@@ -38,6 +38,9 @@ UncertaintyQuantificationToolbox is the collection of tools for Uncertainty Quan
 @copyright: 2012-2014 The Technical University of Denmark
 """
 
+import unittests
+from unittests import *
+
 __all__ = ["RandomSampling","ModelReduction","gPC","sobol_lib","CutANOVA","mcmc"]
 
 __author__ = "Daniele Bigoni"
